@@ -98,7 +98,11 @@ class Env:  # noqa: WPS214
 
     @overload
     def add(
-        self, fn: None = None, *, required: bool, key: Optional[str] = None,
+        self,
+        fn: None = None,
+        *,
+        required: bool,
+        key: Optional[str] = None,
     ) -> Callable[[SourceFn], EnvItem]:  # pragma: no cover
         ...
 
@@ -107,7 +111,10 @@ class Env:  # noqa: WPS214
         ...
 
     def add(
-        self, fn: Optional[SourceFn] = None, required: bool = True, key: Optional[str] = None,
+        self,
+        fn: Optional[SourceFn] = None,
+        required: bool = True,
+        key: Optional[str] = None,
     ) -> Union[EnvItem, Callable[[SourceFn], EnvItem]]:
         # This can be used as a straight decorator, or a parameterized decorator
         #
